//===----------------------------------------------------------------------===//
//
//                     The LLVM Compiler Infrastructure
//
// This file is dual licensed under the MIT and the University of Illinois Open
// Source Licenses. See LICENSE.TXT for details.
//
//===----------------------------------------------------------------------===//

// UNSUPPORTED: c++98, c++03, c++11
// <experimental/chrono>

#include <experimental/chrono>

#ifndef _LIBCPP_CHRONO
#  error "<experimental/chrono> must include <chrono>"
#endif

int main()
{
}
